@@ -57,9 +57,6 @@
  *
  */
 
-typedef AtkImplementorIface AtkImplementorInterface;
-G_DEFINE_INTERFACE (AtkImplementor, atk_implementor, G_TYPE_OBJECT)
-
 static GPtrArray *role_names = NULL;
 
 enum
@@ -680,9 +677,24 @@ atk_object_init  (AtkObject        *accessible,
   accessible->role = ATK_ROLE_UNKNOWN;
 }
 
-static void
-atk_implementor_default_init (AtkImplementorInterface *iface)
+GType
+atk_implementor_get_type (void)
 {
+  static GType type = 0;
+
+  if (!type)
+    {
+      static const GTypeInfo typeInfo =
+      {
+        sizeof (AtkImplementorIface),
+        (GBaseInitFunc) NULL,
+        (GBaseFinalizeFunc) NULL,
+      } ;
+
+      type = g_type_register_static (G_TYPE_INTERFACE, "AtkImplementorIface", &typeInfo, 0) ;
+    }
+
+  return type;
 }
 
 /**
